@@ -22,8 +22,8 @@ class TestWeekendChart(unittest.TestCase):
 
     @vcr.use_cassette(FIXTURES_DIR + '/vcr_cassettes/weekend_chart.yaml')
     def setUp(self):
-        self.bom = BOM()
-        self.movies = self.bom.weekend_chart()
+        self.bom = BOM(WEEKEND_CHART)
+        self.movies = self.bom.get_chart()
         self.test_movie = self.movies.next() # get the first movie for testing
 
     def test_weekend_chart(self):
@@ -35,7 +35,6 @@ class TestWeekendChart(unittest.TestCase):
         assert type(self.test_movie.studio) == str
         assert type(self.test_movie.gross) == str
         assert "$" in self.test_movie.gross
-
         
 
     @vcr.use_cassette(FIXTURES_DIR + '/vcr_cassettes/weekend_trend.yaml')
@@ -44,7 +43,7 @@ class TestWeekendChart(unittest.TestCase):
         Tests for the weekend trend of a movie
         """
         for movie in self.movies:
-            trend_data = movie.weekend_trend()
+            trend_data = movie.get_trend(WEEKEND_CHART)
             assert len(trend_data) > 0
             assert type(trend_data) == list
             for data in trend_data:
